@@ -31,8 +31,12 @@ class TimescaleClient:
         self.db_name = db_name
         self.standardized = standardized
         self.conn = psycopg2.connect(**kwargs)
+        if kwargs.get('PGPORT') == ["5000"]:
+            read_only = False
+        else:
+            read_only = True
         self.conn.set_session(isolation_level="read uncommitted",
-                              readonly=False,
+                              readonly=read_only,
                               autocommit=False)
         self.pk = pk
         self.allowed_aggs = ['first', 'last', 'avg']
