@@ -5,7 +5,6 @@ from pathlib import Path
 
 # Third Party Modules
 import pandas as pd
-import pytz
 import numpy as np
 from dotenv import load_dotenv
 
@@ -35,11 +34,10 @@ def offset_df(df, offset=10):
     """
     for index, row in df.iterrows():
         dt = datetime.strptime(row["measurement_date"],
-                               "%Y-%m-%d %H:%M:%S +10:00") + \
+                               "%Y-%m-%d %H:%M:%S") + \
              timedelta(milliseconds=offset)
-        row["measurement_date"] = "{0} {1}".format(
-            dt.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3],
-            "+10:00")
+        row["measurement_date"] = "{0}".format(
+            dt.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3])
 
 
 def generate_sample_df(dates, device_metrics, schema='narrow'):
@@ -77,7 +75,6 @@ def generate_sample_df(dates, device_metrics, schema='narrow'):
 
 def apply_standard_index(df):
     idx = ['device_id', 'device_metric_type_id', 'measurement_date']
-    # Convert datetime columns to brisbane local time
     df.set_index(idx, inplace=True)
     # Only need the value column
     df.drop(df.columns.difference(['value']), 1, inplace=True)
@@ -85,7 +82,7 @@ def apply_standard_index(df):
     df.index = df.index.set_levels(
         [df.index.levels[0],
          df.index.levels[1],
-         pd.to_datetime(df.index.levels[2])])
+         pd.to_datetime(df.index.levels[2]).tz_convert(None)])
     # Have time displayed from least recent to most recent.
     # Still grouped by device_id, metric_type first
     df.sort_index(inplace=True, ascending=True)
